@@ -26,7 +26,6 @@ import numpy as np
 # Import simulation modules 
 from system import System
 from domain import Domain
-from field import Field
 
 # Import system modules
 from modules.generator import Generator
@@ -50,6 +49,9 @@ from field import fft, ifft, fftshift, ifftshift
 from field import temporal_power, spectral_power
 from field import phase, chirp
 
+# Import pulse width conversion function
+from modules.generator import convert_pulse_width
+
 # Import conversions for dispersion and attenuation
 from modules.linearity import convert_dispersion_to_physical
 from modules.linearity import convert_dispersion_to_engineering
