@@ -20,10 +20,6 @@
 """
 # ==============================================================================
 
-
-# TODO: this is a barebones class. It should not yet be used.
-# Only use the helper functions.
-
 import numpy as np
 import scipy.fftpack
 # ==============================================================================
@@ -149,73 +145,3 @@ def fftshift( A_nu ):
    # ===========================================================================
    return scipy.fftpack.ifftshift( A_nu )
 # ==============================================================================
-class Field( list ):
-   """
-   A field stores an array of complex values representing the envelope of an 
-   optical signal. This class will handle conversions between temporal and 
-   spectral domains, as well as a range of useful calculations on the array.
-   """
-   # ===========================================================================
-   def __init__( self, domain = None ):
-
-      list.__init__( self )
-
-      if( domain is None ):
-         raise Exception( "Must pass domain to field" )
-      else:
-         self.domain = domain
-      # ========================================================================
-      self.clear()
-   # ===========================================================================
-   def clear( self ):
-      if( self.domain.channels > 1 ):
-         self.envelope = [ np.zeros([self.domain.total_samples], complex)
-                           for n in range(self.domain.channels) ]
-      else:
-         self.envelope = np.zeros( [self.domain.total_samples], complex )
-      # ========================================================================
-      self.is_temporal = True
-   # ===========================================================================
-   def set_temporal_domain( self ):
-      if( not self.is_temporal ):
-         fft( self.envelope )
-         is_temporal = True
-   # ===========================================================================
-   def set_spectral_domain( self ):
-      if( is_temporal ):
-         ifft( self.envelope )
-         is_temporal = False
-   # ===========================================================================
-   def power( self, normalise = False ):
-      if( self.is_temporal ):
-         P = np.abs(self.envelope)**2
-      else:
-         P = fftshift( np.abs(self.envelope)**2 )
-      # ========================================================================
-      if( normalise ):
-         P /= max(P)
-      # ========================================================================
-      return P
-   # ===========================================================================
-   def mean_power( self ):
-
-      power_sum = np.sum( self.power )
-      # ========================================================================
-      if( self.is_temporal ):
-         mean_power = power_sum / domain.total_samples
-      else:
-         mean_power = power_sum
-      # ========================================================================
-      return mean_power 
-   # ===========================================================================
-   def total_energy( self ):
-
-      power_sum = np.sum( self.power )
-      # ========================================================================
-      if( self.is_temporal ):
-         total_energy = power_sum * domain.delta_t
-      else:
-         total_energy = power_sum * domain.window_t
-      # ========================================================================
-      return total_energy
-# ==============================================================================
