@@ -20,6 +20,7 @@
 """
 # ==============================================================================
 
+from matplotlib import cm
 import matplotlib.pyplot as plt
 import matplotlib.animation as animation
 from mpl_toolkits.mplot3d import Axes3D
@@ -30,8 +31,8 @@ labels = { "t" : "Time, $t \, (ps)$", \
            "nu" : r"Frequency, $\nu \, (THz)$", \
            "Lambda" : r"Wavelength, $\lambda \, (nm)$", \
            "P_t" : "Power, $|A(z, t)|^2 \, (W)$", \
-           "P_nu" : r"Power, $|A(z, \nu)|^2 \, (a.u.)$", \
-           "P_lambda" : r"Power, $|A(z, \lambda|^2 \, (a.u.)$", \
+           "P_nu" : r"Power, $|\tilde{A}(z, \nu)|^2 \, (a.u.)$", \
+           "P_lambda" : r"Power, $|\tilde{A}(z, \lambda|^2 \, (a.u.)$", \
            "z" : "Fibre length, $z \, (km)$", \
            "phi" : "Phase, $\phi(t) \, (rad)$", \
            "chirp" : "Frequency chirp, $\delta \omega \, (rad / ps)$", \
@@ -41,7 +42,7 @@ labels = { "t" : "Time, $t \, (ps)$", \
 # ==============================================================================
 def map_plot( x, y, z, x_label = "", y_label = "", z_label = "",
               interpolation = 'lanczos', use_colour = True,
-              filename = "", dpi = 100, y_range = None ):
+              filename = "", y_range = None ):
    """
    :param Dvector x: First axis
    :param Dvector y: Second axis
@@ -52,14 +53,11 @@ def map_plot( x, y, z, x_label = "", y_label = "", z_label = "",
    :param string interpolation: Type of interpolation to use
    :param bool use_colour: Use colour plot (else black and white plot)
    :param string filename: Location to save file. If "", use interactive plot
-   :param Uint dpi: Resolution of output image (dots per inch)
    :param Dvector y_range: Change range of second axis if not None
 
    Generate a map plot.
    """
    # ===========================================================================
-   from matplotlib import cm
-
    print "\nGenerating map_plot..."
    plt.clf()
    # ===========================================================================
@@ -86,13 +84,13 @@ def map_plot( x, y, z, x_label = "", y_label = "", z_label = "",
    plt.tight_layout()
    # ===========================================================================
    if( filename ):
-      plt.savefig( filename, dpi = dpi )
+      plt.savefig( filename )
       print "Wrote file", filename
    else:
       plt.show()
 # ==============================================================================
 def waterfall_plot( x, y, z, x_label = "", y_label = "", z_label = "",
-                    use_poly = True, alpha = 0.2, filename = "", dpi = 100,
+                    use_poly = True, alpha = 0.2, filename = "",
                     y_range = None, x_range = None ):
    """
    :param Dvector x: First axis
@@ -104,7 +102,6 @@ def waterfall_plot( x, y, z, x_label = "", y_label = "", z_label = "",
    :param bool use_poly: Whether to use filled polygons
    :param double alpha: Set transparency of filled polygons
    :param string filename: Location to save file. If "", use interactive plot
-   :param Uint dpi: Resolution of output image (dots per inch)
    :param Dvector y_range: Change range of second axis if not None
    :param Dvector x_range: Change range of first axis if not None
 
@@ -150,14 +147,14 @@ def waterfall_plot( x, y, z, x_label = "", y_label = "", z_label = "",
    plt.tight_layout()
    # ===========================================================================
    if( filename ):
-      plt.savefig( filename, dpi = dpi )
+      plt.savefig( filename )
       print "Wrote file", filename
    else:
       plt.show()
 # ==============================================================================
 def single_plot( x, y, x_label = "", y_label = "", label = "", 
                  x_range = None, y_range = None, use_fill = True,
-                 alpha = 0.2, filename = "", dpi = 100 ):
+                 alpha = 0.2, filename = "", style = "b-", fill_colour = "b" ):
    """
    :param Dvector x: First axis
    :param Dvector y: Second axis
@@ -169,7 +166,8 @@ def single_plot( x, y, x_label = "", y_label = "", label = "",
    :param bool use_fill: Fill area between plot line and axis
    :param double alpha: Transparency of filled area
    :param string filename: Location to save file. If "", use interactive plot
-   :param Uint dpi: Resolution of output image (dots per inch)
+   :param string style: Style of plot data. E.g. "g+" plots green plus signs
+   :param string fill_colour: Filled region colour. E.g. "b" uses a blue fill
 
    Generate a single plot.
    """
@@ -177,10 +175,10 @@ def single_plot( x, y, x_label = "", y_label = "", label = "",
    print "\nGenerating single_plot..."
    plt.clf()
    # ===========================================================================
-   plt.plot( x, y, label = label )
+   plt.plot( x, y, style, label = label )
    # ===========================================================================
    if( use_fill ):
-      plt.fill_between( x, y, alpha = alpha )
+      plt.fill_between( x, y, color = fill_colour, alpha = alpha )
    # ===========================================================================
    plt.xlabel( x_label )
    plt.ylabel( y_label )
@@ -194,15 +192,14 @@ def single_plot( x, y, x_label = "", y_label = "", label = "",
       plt.legend()
    # ===========================================================================
    if( filename ):
-      plt.savefig( filename, dpi = dpi )
+      plt.savefig( filename )
       print "Wrote file", filename
    else:
       plt.show()
 # ==============================================================================
 def double_plot( x, y, X, Y, x_label = "", y_label = "", X_label = "",
                  Y_label = "", x_range = None, y_range = None, X_range = None,
-                 Y_range = None, use_fill = True, alpha = 0.2,
-                 filename = "", dpi = 100 ):
+                 Y_range = None, use_fill = True, alpha = 0.2, filename = "" ):
    """
    :param Dvector x: First axis of upper plot
    :param Dvector y: Second axis of upper plot
@@ -219,7 +216,6 @@ def double_plot( x, y, X, Y, x_label = "", y_label = "", X_label = "",
    :param bool use_fill: Fill area between plot line and axis
    :param double alpha: Transparency of filled area
    :param string filename: Location to save file. If "", use interactive plot
-   :param Uint dpi: Resolution of output image (dots per inch)
 
    Generate a double plot. The two plots will be arranged vertically, one above 
    the other.
@@ -259,18 +255,18 @@ def double_plot( x, y, X, Y, x_label = "", y_label = "", X_label = "",
    plt.tight_layout()
    # ===========================================================================
    if( filename ):
-      plt.savefig( filename, dpi = dpi )
+      plt.savefig( filename )
       print "Wrote file", filename
    else:
       plt.show()
 # ==============================================================================
-def multi_plot( x, ys, zs, x_label = "", y_label = "", z_labels = [""],
-                x_range = None, y_range = None, use_fill = True, alpha = 0.2,
-                filename = "", dpi = 100 ):
+def multi_plot( x, ys, zs = [], x_label = "", y_label = "",
+                z_labels = [""], x_range = None, y_range = None,
+                use_fill = True, alpha = 0.2, filename = "" ):
    """
    :param Dvector x: First axis
    :param VDvector ys: Array of second axis
-   :param VDvector zs: Array of third axis
+   :param VDvector zs: Array of third axis (used for legend, and colours)
    :param string x_label: Label for first axis
    :param string y_label: Label for second axis
    :param Vstring: List of strings for third axis
@@ -279,9 +275,8 @@ def multi_plot( x, ys, zs, x_label = "", y_label = "", z_labels = [""],
    :param bool use_fill: Fill area between plot line and axis
    :param double alpha: Transparency of filled area
    :param string filename: Location to save file. If "", use interactive plot
-   :param Uint dpi: Resolution of output image (dots per inch)
 
-   Generate a multiple overlapping plots.
+   Generate multiple overlapping plots.
    """
    # ===========================================================================
    print "\nGenerating multi_plot..."
@@ -311,17 +306,20 @@ def multi_plot( x, ys, zs, x_label = "", y_label = "", z_labels = [""],
    if( y_range is not None ):
       plt.ylim( y_range )
    # ===========================================================================
-   plt.legend()
+   # Try to place legend in best location (avoiding plot):
+   leg = plt.legend( loc = "best", fancybox = True )
+   # Use a semi-transparent legend box in case of overlap with plot:
+   leg.get_frame().set_alpha(0.5)
    # ===========================================================================
    if( filename ):
-      plt.savefig( filename, dpi = dpi )
+      plt.savefig( filename )
       print "Wrote file", filename
    else:
       plt.show()
 # ==============================================================================
 def quad_plot( x, ys, zs, x_label = "", y_label = "", z_labels = [""],
-               x_range = None, y_range = None, use_fill = True, alpha = 0.2,
-               filename = "", dpi = 100 ):
+               x_range = None, y_range = None,
+               use_fill = True, alpha = 0.2, filename = "" ):
    """
    :param Dvector x: First axis
    :param VDvector ys: Array of second axis
@@ -334,7 +332,6 @@ def quad_plot( x, ys, zs, x_label = "", y_label = "", z_labels = [""],
    :param bool use_fill: Fill area between plot line and axis
    :param double alpha: Transparency of filled area
    :param string filename: Location to save file. If "", use interactive plot
-   :param Uint dpi: Resolution of output image (dots per inch)
 
    Generate four plots arranged in a two-by-two square.
    """
@@ -364,7 +361,10 @@ def quad_plot( x, ys, zs, x_label = "", y_label = "", z_labels = [""],
       if( y_range is not None ):
          axs[n].set_ylim( y_range )
       # ========================================================================
-      axs[n].legend( loc = (0.0, 1.0) )
+      # Try to place legend in best location (avoiding plot):
+      leg = axs[n].legend( loc = "best", fancybox = True )
+      # Use a semi-transparent legend box in case of overlap with plot:
+      leg.get_frame().set_alpha(0.5)
    # ===========================================================================
    ax1.set_ylabel( y_label )
    ax3.set_ylabel( y_label )
@@ -375,7 +375,7 @@ def quad_plot( x, ys, zs, x_label = "", y_label = "", z_labels = [""],
    plt.tight_layout()
    # ===========================================================================
    if( filename ):
-      plt.savefig( filename, dpi = dpi )
+      plt.savefig( filename )
       print "Wrote file", filename
    else:
       plt.show()
@@ -471,115 +471,3 @@ def convert_video( filename, output = "ogv" ):
    # ===========================================================================
    print "\nWrote file", '.'.join( (out_file, output) )
 # ==============================================================================
-# ==============================================================================
-def generate_frames( x, y, z, x_label = "", y_label = "", z_label = "",
-                     x_range = None, y_range = None,
-                     filepath = "dat/", dpi = 100 ):
-   """
-   :param Dvector x: First axis
-   :param VDvector y: Array of second axis
-   :param Dvector z: Third axis
-   :param string x_label: Label for first axis
-   :param string y_label: Label for second axis
-   :param string z_label: label for third axis
-   :param Dvector x_range: Change range of first axis if not None
-   :param Dvector y_range: Change range of second axis if not None
-   :param string filepath: Location to store each frame (plot)
-   :param Uint dpi: Resolution of output image (dots per inch)
-
-   Generate multiple plots, storing each in a directory given by filepath.
-
-   .. deprecated:: 0.7
-      Use :func:`animated_plot` instead.
-      This function may be removed before version 1.0 is released.
-   """
-   # ===========================================================================
-   print "\nGenerating frames..."
-   plt.clf()
-   # ===========================================================================
-   for i in range( len(y) ):
-      plt.xlabel( x_label )
-      plt.ylabel( y_label )
-      # ========================================================================
-      plt.plot( x, y[i], 'b-', label = z_label.format(z[i]) )
-      plt.fill_between( x, y[i], facecolor = 'blue', alpha = 0.2 )
-      if( x_range is not None ):
-         plt.xlim( x_range )
-      if( y_range is not None ):
-         plt.ylim( y_range )
-      # ========================================================================
-      plt.legend()
-      # ========================================================================
-      filename = filepath + str('%03d' % i) + '.png'
-      plt.savefig( filename, dpi = dpi )
-      print "Wrote file", filename
-      # ========================================================================
-      plt.clf()
-# ==============================================================================
-def generate_movie( data_path = 'dat/', width = 640, height = 480,
-                    fps = 5, filename = "output.avi" ):
-   """
-   :param string data_path: Location of directory containing frames (plots)
-   :param Uint width: Width of movie
-   :param Uint height: Height of movie
-   :param Uint fps: Number of frames to show every second (frames per second)
-   :param string filename: Output filename for movie
-
-   Stitch together multiple plots found in data_path directory to form a movie.
-
-   .. deprecated:: 0.7
-      Use :func:`animated_plot` instead.
-      This function may be removed before version 1.0 is released.
-   """
-   # ===========================================================================
-   command = ('mencoder', 'mf://{0}*.png'.format( data_path ), '-mf',
-              'type=png:w={0}:h={1}:fps={2}'.format(width, height, fps),
-              '-ovc', 'lavc', '-lavcopts', 'vcodec=mpeg4', '-oac', 'copy',
-              '-o', '{0}'.format( filename ) )
-   # ===========================================================================
-   #os.spawnvp(os.P_WAIT, 'mencoder', command)
-   # ===========================================================================
-   print "\n\nExecuting command:\n%s\n\n" % ' '.join( command )
-   subprocess.check_call( command )
-   # ===========================================================================
-   print "\nWrote file", filename
-# ==============================================================================
-def convert_movie( filename, output = "ogv" ):
-   """
-   :param string filename: Location of movie file to convert
-   :param string output: Convert movie to output video type
-
-   Convert video to ogv, webm, or mp4 type.
-
-   .. deprecated:: 0.7
-      Use :func:`convert_video` instead.
-      This function may be removed before version 1.0 is released.
-   """
-   # ===========================================================================
-   import os
-   out_file = os.path.splitext( filename )[0]
-
-   if( output == "ogv" ):
-      # Use Theora/Vorbis codecs
-      command = ('ffmpeg2theora', '{0}'.format( filename ))
-#      command = ('ffmpeg', '-i', '{0}'.format( filename ), '-b', '1500k',
-#                 '-vcodec', 'libtheora', '-acodec', 'libvorbis', '-ab',
-#                 '160000', '-g', '30',
-#                 '{0}'.format( '.'.join((out_file, output)) ))
-   elif( output == "webm" ):
-      # Use VP8/Vobis codecs
-      command = ('ffmpeg', '-i', '{0}'.format( filename ), '-b', '1500k',
-                 '-vcodec', 'libvpx', '-acodec', 'libvorbis', '-ab',
-                 '160000', '-f', 'webm', '-g', '30',
-                 '{0}'.format( '.'.join((out_file, output)) ))
-   elif( output == "mp4" ):
-      # Use H.264/ACC codecs
-      command = ('ffmpeg', '-i', '{0}'.format( filename ), '-b', '1500k',
-                 '-vcodec', 'libx264', '-vpre', 'slow', '-vpre', 'baseline',
-                 '-g', '30', '{0}'.format( '.'.join((out_file, output)) ))
-
-   print "\n\nConverting video using command:\n%s\n\n" % ' '.join( command )
-   subprocess.check_call( command )
-   # ===========================================================================
-   print "\nWrote file", '.'.join( (out_file, output) )
-# ==============================================================================
