@@ -38,7 +38,7 @@ A_{n+1}^{*} = A_n + h s_\mu k_\mu
 e_{n+1} = A_{n+1} - A_{n+1}^{*} = h (r_\mu - s_mu) k^\mu
 """
 # ==============================================================================
-class Solver():
+class Solver( object ):
    """
    :param string method: Name of solver method to be used
    :param object f: Derivative function
@@ -243,65 +243,6 @@ class Solver():
       return A_fine, A_coarse
    # ===========================================================================
    # ===========================================================================
-   def ssfm( self, A, z, h, f ):
-      """
-
-      .. deprecated:: 0.8
-         Use :func:`ss_simple` instead.
-         This function may be removed before version 1.0 is released.
-      """
-      return self.ss_simple( A, z, h, f )
-   # ===========================================================================
-   def ssfm_reduced( self, A, z, h, f ):
-      """
-
-      .. deprecated:: 0.8
-         Use :func:`ss_reduced` instead.
-         This function may be removed before version 1.0 is released.
-      """
-      return self.ss_reduced( A, z, h, f )
-   # ===========================================================================
-   def ssfm_sym( self, A, z, h, f ):
-      """
-
-      .. deprecated:: 0.8
-         Use :func:`ss_symmetric` instead.
-         This function may be removed before version 1.0 is released.
-      """
-      return self.ss_symmetric( A, z, h, f )
-   # ===========================================================================
-   def ssfm_sym_midpoint( self, A, z, h, f ):
-      """
-
-      .. deprecated:: 0.8
-         Use :func:`ss_sym_midpoint` instead.
-         This function may be removed before version 1.0 is released.
-      """
-      return self.ss_sym_midpoint( A, z, h, f )
-   # ===========================================================================
-   def ssfm_sym_rk4( self, A, z, h, f ):
-      """
-
-      .. deprecated:: 0.8
-         Use :func:`ss_sym_rk4` instead.
-         This function may be removed before version 1.0 is released.
-      """
-      return self.ss_sym_rk4( A, z, h, f )
-   # ===========================================================================
-   def ssfm_sym_rkf( self, A, z, h, f ):
-      """
-
-      .. deprecated:: 0.8
-         This function may be removed before version 1.0 is released.
-      """
-
-      A_L = f.linear( A, 0.5 * h )
-      # Embedded methods return a two-element tuple:
-      A_Nf, A_Nc = self.rkf( A_L, z, h, f.n )
-
-      return f.linear( A_Nf, 0.5 * h )
-   # ===========================================================================
-   # ===========================================================================
    def ss_simple( self, A, z, h, f ):
       """ Simple split-step method """
 
