@@ -27,7 +27,7 @@ from storage import reduce_to_range
 from storage import Storage
 from solver import Solver
 # ==============================================================================
-class Stepper():
+class Stepper( object ):
    """
    :param Uint traces: Number of ouput trace to use
    :param double local_error: Relative local error required in adaptive method
@@ -89,7 +89,7 @@ class Stepper():
       # ========================================================================
       # Store constants for adaptive method:
       self.total_attempts = 100
-      self.steps_max = 4000
+      self.steps_max = 50000
 
       self.safety = 0.9
       self.max_factor = 10.0
@@ -155,7 +155,13 @@ class Stepper():
    def relative_local_error( self, A_fine, A_coarse ):
       """ Calculate an estimate of the relative local error """
 
-      return linalg.norm( A_fine - A_coarse ) / linalg.norm( A_fine )
+      norm_fine = linalg.norm( A_fine )
+      # ========================================================================
+      # Avoid possible divide by zero:
+      if( norm_fine != 0.0 ):
+         return linalg.norm( A_fine - A_coarse ) / norm_fine
+      else:
+         return linalg.norm( A_fine - A_coarse )
    # ===========================================================================
    def adaptive_stepper( self, A ):
       """ Take multiple steps, with variable length, until target reached """
@@ -214,16 +220,17 @@ class Stepper():
             # Store current stepsize:
             h_temp = h
             # ==================================================================
-            if( delta > 2.0 * self.local_error ):
-               # local error estimate too large, half stepsize and repeat step:
-               h = 0.5 * h_temp
-            else:
-               # Keep solution and use delta to adjust stepsize for next step:
+            # Adjust stepsize for next step:
+            if( delta > 0.0 ):
                error_ratio = (self.local_error / delta)
                factor = self.safety * np.power( error_ratio, 1.0 / self.eta )
                h = h_temp * min( self.max_factor, max(self.min_factor, factor) )
-               # ===============================================================
-               # Completed propagation along z by stepsize h_temp, so update z:
+            else:
+               # Error approximately zero so use largest stepsize increase:
+               h = h_temp * self.max_factor
+            # ==================================================================
+            if( delta < 2.0 * self.local_error ):
+               # Successful step, so increment z by the stepsize used; h_temp:
                z += h_temp
                # ===============================================================
                if( self.solver.embedded ):
@@ -240,7 +247,10 @@ class Stepper():
                if( self.traces != 1 ):
                   self.storage.append( z, self.A_out )
                # ===============================================================
-               break
+               break # Successful attempt at step, move on to next step.
+            # ==================================================================
+            # Otherwise error was too large, continue with next attempt.
+            # ==================================================================
          else:
             raise Exception( "Failed to set suitable step-size" )
          # =====================================================================
