@@ -69,7 +69,7 @@ def reduce_to_range( x, ys, first_value, last_value ):
    else:
       print "Cannot reduce storage arrays unless last_value > first_value"
 # ==============================================================================
-class Storage():
+class Storage( object ):
    """ 
    Contains A arrays for multiple z values. Also contains t array and functions 
    to modify the stored data.
@@ -157,45 +157,6 @@ class Storage():
       index = ( np.abs(array - value) ).argmin()
       return index, array[index]
    # ===========================================================================
-   def reduce_to_range( self, first_t, last_t ):
-      """
-      :param double first_t: Initial value of temporal range
-      :param double last_t: Final value of temporal range
-
-      Reduce the size of stored arrays, As and t.
-      Start by finding left and right index corresponding to first_t and last_t 
-      respectively. Use these indices to slice both t array and As array.
-
-      .. deprecated:: 0.8
-         Use non-member :func:`reduce_to_range` instead.
-         This function may be removed before version 1.0 is released.
-      """
-      # ========================================================================
-      print "Attempting to reduce storage arrays to specified range..."
-      if( last_t > first_t ):
-
-         first_index, t_first = self.find_nearest( self.t, first_t )
-         last_index, t_last = self.find_nearest( self.t, last_t )
-         # =====================================================================
-         print "Required range: [{0}, {1}]\nActual range: [{2}, {3}]".format( \
-               first_t, last_t, t_first, t_last ) 
-         # =====================================================================
-         # The returned slice does NOT include the second index parameter. To 
-         # include the element corresponding to last_index, the second index 
-         # parameter should be last_index + 1:         
-         self.t = self.t[first_index : last_index + 1]
-
-         # As is a list of arrays. Does each array contain additional arrays:
-         import collections
-         if( isinstance(self.As[0][0], collections.Iterable) ):
-            self.As = [ [A_c0[first_index : last_index + 1],
-                         A_c1[first_index : last_index + 1]]
-                        for (A_c0, A_c1) in self.As ]
-         else:
-            self.As = [ A[first_index : last_index + 1] for A in self.As ]
-      else:
-         print "Cannot reduce storage arrays unless last_t > first_t"
-   # ===========================================================================
    def interpolate_As_for_z_values( self, zs ):
       """ 
       :param array_like zs: Array of z values for which A is required
